@@ -29,9 +29,7 @@ class Command(BaseCommand):
             help="Specify the package name, or show this package if not given",
         )
         for option in self.metadata_keys:
-            parser.add_argument(
-                f"--{option}", action="store_true", help=f"Show {option}"
-            )
+            parser.add_argument(f"--{option}", action="store_true", help=f"Show {option}")
 
     def handle(self, project: Project, options: argparse.Namespace) -> None:
         package = options.package
@@ -45,7 +43,7 @@ class Command(BaseCommand):
                 project.core.ui.echo(
                     f"No match found for the package {package!r}",
                     err=True,
-                    style="yellow",
+                    style="warning",
                 )
                 return
             latest_stable = next(filter(filter_stable, matches), None)
@@ -53,8 +51,8 @@ class Command(BaseCommand):
         else:
             if not project.name:
                 raise PdmUsageError("This project is not a package")
-            metadata = project.meta
-            package = normalize_name(metadata.name)
+            package = normalize_name(project.name)
+            metadata = project.make_self_candidate().prepare(project.environment).metadata
             latest_stable = None
         assert metadata
         project_info = ProjectInfo(metadata)
