@@ -48,8 +48,7 @@ def compress_for_rename(paths: Iterable[str]) -> set[str]:
     unchecked = sorted({os.path.split(p)[0] for p in case_map.values()}, key=len)
     wildcards: set[str] = set()
 
-    def norm_join(*a):
-        # type: (str) -> str
+    def norm_join(*a: str) -> str:
         return os.path.normcase(os.path.join(*a))
 
     for root in unchecked:
@@ -58,10 +57,13 @@ def compress_for_rename(paths: Iterable[str]) -> set[str]:
             continue
 
         all_files: set[str] = set()
-        all_subdirs: set[str] = set()
         for dirname, subdirs, files in os.walk(root):
-            all_subdirs.update(norm_join(root, dirname, d) for d in subdirs)
             all_files.update(norm_join(root, dirname, f) for f in files)
+            for d in subdirs:
+                norm_path = norm_join(root, dirname, d)
+                if os.path.islink(norm_path):
+                    all_files.add(norm_path)
+
         # If all the files we found are in our remaining set of files to
         # remove, then remove them from the latter set and add a wildcard
         # for the directory.
@@ -122,9 +124,11 @@ class BaseRemovePaths(abc.ABC):
     def remove(self) -> None:
         """Remove the files"""
 
+    @abc.abstractmethod
     def commit(self) -> None:
         """Commit the removal"""
 
+    @abc.abstractmethod
     def rollback(self) -> None:
         """Roll back the removal operations"""
 
@@ -133,7 +137,7 @@ class BaseRemovePaths(abc.ABC):
         """Create an instance from the distribution"""
         scheme = environment.get_paths()
         instance = cls(dist, environment)
-        meta_location = os.path.normcase(dist._path.absolute())  # type: ignore
+        meta_location = os.path.normcase(dist._path.absolute())  # type: ignore[attr-defined]
         dist_location = os.path.dirname(meta_location)
         if is_egg_link(dist):  # pragma: no cover
             egg_link_path = cast("Path | None", getattr(dist, "link_file", None))
@@ -143,9 +147,7 @@ class BaseRemovePaths(abc.ABC):
                     dist.metadata["Name"],
                 )
             else:
-                link_pointer = os.path.normcase(
-                    egg_link_path.open("rb").readline().decode().strip()
-                )
+                link_pointer = os.path.normcase(egg_link_path.open("rb").readline().decode().strip())
                 if link_pointer != dist_location:
                     raise UninstallError(
                         f"The link pointer in {egg_link_path} doesn't match "
@@ -203,9 +205,7 @@ class StashedRemovePaths(BaseRemovePaths):
 
     def __init__(self, dist: Distribution, environment: Environment) -> None:
         super().__init__(dist, environment)
-        self._pth_file = os.path.join(
-            self.environment.get_paths()["purelib"], self.PTH_REGISTRY
-        )
+        self._pth_file = os.path.join(self.environment.get_paths()["purelib"], self.PTH_REGISTRY)
         self._saved_pth: bytes | None = None
         self._stashed: list[tuple[str, str]] = []
         self._tempdirs: dict[str, TemporaryDirectory] = {}
@@ -234,18 +234,14 @@ class StashedRemovePaths(BaseRemovePaths):
             if not os.path.exists(old_path):
                 continue
             is_dir = os.path.isdir(old_path) and not os.path.islink(old_path)
-            termui.logger.debug(
-                "Removing %s %s", "directory" if is_dir else "file", old_path
-            )
+            termui.logger.debug("Removing %s %s", "directory" if is_dir else "file", old_path)
             if old_path.endswith(".pyc"):
                 # Don't stash cache files, remove them directly
                 os.unlink(old_path)
                 continue
             root = _get_file_root(old_path, prefix)
             if root is None:
-                termui.logger.debug(
-                    "File path %s is not under packages root %s, skip", old_path, prefix
-                )
+                termui.logger.debug("File path %s is not under packages root %s, skip", old_path, prefix)
                 continue
             if root not in self._tempdirs:
                 self._tempdirs[root] = TemporaryDirectory("-uninstall", "pdm-")
